===============================
sndict
===============================


.. image:: https://img.shields.io/pypi/v/sndict.svg
        :target: https://pypi.python.org/pypi/sndict

.. image:: https://img.shields.io/travis/zphang/sndict.svg
        :target: https://travis-ci.org/zphang/sndict

.. image:: https://readthedocs.org/projects/sndict/badge/?version=latest
        :target: https://sndict.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/zphang/sndict/shield.svg
     :target: https://pyup.io/repos/github/zphang/sndict/
     :alt: Updates


Nested Extensions to Python dictionaries

* Free software: MIT license
* Documentation: https://sndict.readthedocs.io.


Introduction
------------
This module provides extensions to ``dicts`` in the python standard library, providing fast and clean manipulation of nested dictionary structures. This module exposes two new ``dict``-types: ``NestedDict``/``ndict`` and ``StructuredNestedDict``/``sndict``/


Features
--------

* TODO
